<template>
  <a-card
    :bordered="false"
    :class="'cust-erp-sub-tab'"
  >
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div
      class="table-operator"
      v-if="mainId"
    >
      <!-- <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item key="1" @click="batchDel"><a-icon type="delete"/>删除</a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作 <a-icon type="down" /></a-button>
      </a-dropdown> -->
    </div>

    <!-- table区域-begin -->
    <div>
      <div
        class="ant-alert ant-alert-info"
        style="margin-bottom: 16px;"
      >
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a
          style="margin-left: 24px"
          @click="onClearSelected"
        >清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :scroll="{x:true}"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        @change="handleTableChange"
      >

        <template
          slot="htmlSlot"
          slot-scope="text"
        >
          <div v-html="text"></div>
        </template>
        <template
          slot="imgSlot"
          slot-scope="text,record"
        >
          <span
            v-if="!text"
            style="font-size: 12px;font-style: italic;"
          >无图片</span>
          <img
            v-else
            :src="getImgView(text)"
            :preview="record.id"
            height="25px"
            alt=""
            style="max-width:80px;font-size: 12px;font-style: italic;"
          />
        </template>
        <template
          slot="fileSlot"
          slot-scope="text"
        >
          <span
            v-if="!text"
            style="font-size: 12px;font-style: italic;"
          >无文件</span>
          <a-button
            v-else
            :ghost="true"
            type="primary"
            icon="download"
            size="small"
            @click="downloadFile(text)"
          >
            下载
          </a-button>
        </template>

        <span
          slot="action"
          slot-scope="text, record"
        >
          <!-- <a-divider type="vertical" />
          <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
            <a>删除</a>
          </a-popconfirm>  -->
          <a
            @click="handleEdit(record)"
            :disabled="mainStatus!=='distributed'"
          >计划变更</a>
        </span>
        <span
          slot="num"
          slot-scope="text, record"
        >
          <a
            class="lot"
            @click="handleShowDetail(record)"
          >{{record.standardNum}}</a>
        </span>
      </a-table>
    </div>
    <standard-detail-model
      :mainId="standardId"
      ref="standardDetail"
    ></standard-detail-model>
    <maintenance-plan-change-model
      ref="modalForm"
      @ok="modalFormOk"
    ></maintenance-plan-change-model>
  </a-card>
</template>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import StandardDetailModel from './modules/maintenancePlan/StandardDetailModel'
import MaintenancePlanChangeModel from './modules/maintenancePlan/MaintenancePlanChangeModel.vue'
export default {
  name: "EquipmentMaintenancePlanDetailList",
  mixins: [JeecgListMixin],
  components: { StandardDetailModel, MaintenancePlanChangeModel },
  props: {
    mainId: {
      type: String,
      default: '',
      required: false
    },
    mainStatus: {
      type: String,
      default: '',
      required: false
    }
  },
  watch: {
    mainId: {
      immediate: true,
      handler(val) {
        if (!this.mainId) {
          this.clearList()
        } else {
          this.queryParam['planId'] = val
          this.loadData(1);
        }
      }
    }
  },
  data() {
    return {
      description: '保养计划管理页面',
      disableMixinCreated: true,
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 45,
          align: "center",
          customRender: function (t, r, index) {
            return parseInt(index) + 1;
          }
        },
        {
          title: '保养标准',
          align: "center",
          dataIndex: 'standardNum',
          width: 250,
        },
        // scopedSlots: { customRender: 'num' }
        {
          title: '设备统一编码',
          align: "center",
          dataIndex: 'equipmentNum',
          width: 250,
        },
        {
          title: '设备名称',
          align: "center",
          dataIndex: 'equipmentName',
          width: 250,
        },
        {
          title: '设备型号',
          align: "center",
          dataIndex: 'model',
          width: 250,
        },
        {
          title: '计划开始时间',
          align: "center",
          dataIndex: 'planStartTime',
          width: 280,
        },
        {
          title: '计划结束时间',
          align: "center",
          dataIndex: 'planEndTime',
          width: 280,
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: "center",
          fixed: "right",
          width: 200,
          scopedSlots: { customRender: 'action' },
        }
      ],
      url: {
        list: "/eam/equipmentMaintenancePlan/listEquipmentMaintenancePlanDetailByMainId",
        delete: "/eam/equipmentMaintenancePlan/deleteEquipmentMaintenancePlanDetail",
        deleteBatch: "/eam/equipmentMaintenancePlan/deleteBatchEquipmentMaintenancePlanDetail",
        exportXlsUrl: "/eam/equipmentMaintenancePlan/exportEquipmentMaintenancePlanDetail",
        importUrl: "/eam/equipmentMaintenancePlan/importEquipmentMaintenancePlanDetail",
      },
      dictOptions: {
      },
      standardId: ''
    }
  },
  created() {
  },
  computed: {
    importExcelUrl() {
      return `${window._CONFIG['domianURL']}/${this.url.importUrl}/${this.mainId}`;
    }
  },
  methods: {
    clearList() {
      this.dataSource = []
      this.selectedRowKeys = []
      this.ipagination.current = 1
    },
    handleShowDetail(record) {
      this.standardId = record.standardId
      this.$refs.standardDetail.visible = true;
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>
